==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTreeItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescription } from "./WebTreeItemDescription";
/**
 * @hidden
 */
export let WebTreeItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeItemDescriptionMetadata.a == null) {
                WebTreeItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeItemDescriptionMetadata.c(WebTreeItemDescriptionMetadata.a);
            }
            if (a.j(WebTreeItemDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTreeItemDescriptionMetadata.a);
            WebTreeItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeItem");
            a.item("__tagNameWC", "String:igc-tree-item");
            a.item("Parent", "ExportedType:WebTreeItem");
            a.item("Level", "Number:double");
            a.item("Label", "String");
            a.item("Expanded", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Loading", "Boolean");
            a.item("Value", "Unknown");
        }
        static d(a) {
            WebTreeItemDescriptionMetadata.b(a);
            a.aa("WebTreeItem", () => new WebTreeItemDescription());
            a.z("WebTreeItem", WebTreeItemDescriptionMetadata.a);
        }
    }
    WebTreeItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeItemDescriptionMetadata, 'WebTreeItemDescriptionMetadata');
    WebTreeItemDescriptionMetadata.a = null;
    return WebTreeItemDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTreeItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescription } from "./WebTreeItemDescription";
/**
 * @hidden
 */
export let WebTreeItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeItemDescriptionMetadata.a == null) {
                WebTreeItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeItemDescriptionMetadata.c(WebTreeItemDescriptionMetadata.a);
            }
            if (a.k(WebTreeItemDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTreeItemDescriptionMetadata.a);
            WebTreeItemDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeItem");
            a.item("__tagNameWC", "String:igc-tree-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Parent", "ExportedType:WebTreeItem");
            a.item("Level", "Number:double");
            a.item("Label", "String");
            a.item("Expanded", "Boolean");
            a.item("Active", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Loading", "Boolean");
            a.item("Value", "Unknown");
        }
        static d(a) {
            WebTreeItemDescriptionMetadata.b(a);
            a.ac("WebTreeItem", () => new WebTreeItemDescription());
            a.ab("WebTreeItem", WebTreeItemDescriptionMetadata.a);
        }
    }
    WebTreeItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeItemDescriptionMetadata, 'WebTreeItemDescriptionMetadata');
    WebTreeItemDescriptionMetadata.a = null;
    return WebTreeItemDescriptionMetadata;
})();
